@@ -21,26 +21,26 @@ pub struct Constraint {
     /// * `organizations/{organization_id}/constraints/{constraint_name}`
     ///
     /// For example, "/projects/123/constraints/compute.disableSerialPortAccess".
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// The human readable name.
     ///
     /// Mutable.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub display_name: ::prost::alloc::string::String,
     /// Detailed description of what this `Constraint` controls as well as how and
     /// where it is enforced.
     ///
     /// Mutable.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub description: ::prost::alloc::string::String,
     /// The evaluation behavior of this constraint in the absence of 'Policy'.
-    #[prost(enumeration = "constraint::ConstraintDefault", tag = "4")]
+    #[prost(enumeration="constraint::ConstraintDefault", tag="4")]
     pub constraint_default: i32,
     /// The type of restrictions for this `Constraint`.
     ///
     /// Immutable after creation.
-    #[prost(oneof = "constraint::ConstraintType", tags = "5, 6")]
+    #[prost(oneof="constraint::ConstraintType", tags="5, 6")]
     pub constraint_type: ::core::option::Option<constraint::ConstraintType>,
 }
 /// Nested message and enum types in `Constraint`.
@@ -52,13 +52,13 @@ pub mod constraint {
         /// Indicates whether values grouped into categories can be used in
         /// `Policy.allowed_values` and `Policy.denied_values`. For example,
         /// `"in:Python"` would match any value in the 'Python' group.
-        #[prost(bool, tag = "1")]
+        #[prost(bool, tag="1")]
         pub supports_in: bool,
         /// Indicates whether subtrees of Cloud Resource Manager resource hierarchy
         /// can be used in `Policy.allowed_values` and `Policy.denied_values`. For
         /// example, `"under:folders/123"` would match any resource under the
         /// 'folders/123' folder.
-        #[prost(bool, tag = "2")]
+        #[prost(bool, tag="2")]
         pub supports_under: bool,
     }
     /// A `Constraint` that is either enforced or not.
@@ -67,7 +67,8 @@ pub mod constraint {
     /// If it is enforced on a VM instance, serial port connections will not be
     /// opened to that instance.
     #[derive(Clone, PartialEq, ::prost::Message)]
-    pub struct BooleanConstraint {}
+    pub struct BooleanConstraint {
+    }
     /// Specifies the default behavior in the absence of any `Policy` for the
     /// `Constraint`. This must not be `CONSTRAINT_DEFAULT_UNSPECIFIED`.
     ///
@@ -91,10 +92,10 @@ pub mod constraint {
     #[derive(Clone, PartialEq, ::prost::Oneof)]
     pub enum ConstraintType {
         /// Defines this constraint as being a ListConstraint.
-        #[prost(message, tag = "5")]
+        #[prost(message, tag="5")]
         ListConstraint(ListConstraint),
         /// Defines this constraint as being a BooleanConstraint.
-        #[prost(message, tag = "6")]
+        #[prost(message, tag="6")]
         BooleanConstraint(BooleanConstraint),
     }
 }
@@ -114,14 +115,14 @@ pub struct Policy {
     /// Note: `projects/{project_id}/policies/{constraint_name}` is also an
     /// acceptable name for API requests, but responses will return the name using
     /// the equivalent project number.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// Basic information about the Organization Policy.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub spec: ::core::option::Option<PolicySpec>,
     /// Deprecated.
     #[deprecated]
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub alternate: ::core::option::Option<AlternatePolicySpec>,
 }
 /// Similar to PolicySpec but with an extra 'launch' field for launch reference.
@@ -131,10 +132,10 @@ pub struct AlternatePolicySpec {
     /// Reference to the launch that will be used while audit logging and to
     /// control the launch.
     /// Should be set only in the alternate policy.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub launch: ::prost::alloc::string::String,
     /// Specify `Constraint` for configurations of Cloud Platform resources.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub spec: ::core::option::Option<PolicySpec>,
 }
 /// Defines a Cloud Organization `PolicySpec` which is used to specify
@@ -152,12 +153,12 @@ pub struct PolicySpec {
     ///
     /// When the `Policy` is returned from a `GetEffectivePolicy` request, the
     /// `etag` will be unset.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub etag: ::prost::alloc::string::String,
     /// Output only. The time stamp this was previously updated. This
     /// represents the last time a call to `CreatePolicy` or `UpdatePolicy` was
     /// made for that `Policy`.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub update_time: ::core::option::Option<::prost_types::Timestamp>,
     /// Up to 10 PolicyRules are allowed.
     ///
@@ -167,7 +168,7 @@ pub struct PolicySpec {
     ///     of the PolicyRule without a condition.
     ///   - During policy evaluation, PolicyRules with conditions that are
     ///     true for a target resource take precedence.
-    #[prost(message, repeated, tag = "3")]
+    #[prost(message, repeated, tag="3")]
     pub rules: ::prost::alloc::vec::Vec<policy_spec::PolicyRule>,
     /// Determines the inheritance behavior for this `Policy`.
     ///
@@ -176,7 +177,7 @@ pub struct PolicySpec {
     /// effective policy. If it is false, then no rules are inherited, and this
     /// Policy becomes the new root for evaluation.
     /// This field can be set only for Policies which configure list constraints.
-    #[prost(bool, tag = "4")]
+    #[prost(bool, tag="4")]
     pub inherit_from_parent: bool,
     /// Ignores policies set above this resource and restores the
     /// `constraint_default` enforcement behavior of the specific `Constraint` at
@@ -184,7 +185,7 @@ pub struct PolicySpec {
     /// This field can be set in policies for either list or boolean
     /// constraints. If set, `rules` must be empty and `inherit_from_parent`
     /// must be set to false.
-    #[prost(bool, tag = "5")]
+    #[prost(bool, tag="5")]
     pub reset: bool,
 }
 /// Nested message and enum types in `PolicySpec`.
@@ -204,9 +205,9 @@ pub mod policy_spec {
         /// "resource.matchTag('123456789/environment,
         /// 'prod')". or "resource.matchTagId('tagKeys/123',
         /// 'tagValues/456')".
-        #[prost(message, optional, tag = "5")]
+        #[prost(message, optional, tag="5")]
         pub condition: ::core::option::Option<super::super::super::super::r#type::Expr>,
-        #[prost(oneof = "policy_rule::Kind", tags = "1, 2, 3, 4")]
+        #[prost(oneof="policy_rule::Kind", tags="1, 2, 3, 4")]
         pub kind: ::core::option::Option<policy_rule::Kind>,
     }
     /// Nested message and enum types in `PolicyRule`.
@@ -229,30 +230,30 @@ pub mod policy_spec {
         #[derive(Clone, PartialEq, ::prost::Message)]
         pub struct StringValues {
             /// List of values allowed at this resource.
-            #[prost(string, repeated, tag = "1")]
+            #[prost(string, repeated, tag="1")]
             pub allowed_values: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
             /// List of values denied at this resource.
-            #[prost(string, repeated, tag = "2")]
+            #[prost(string, repeated, tag="2")]
             pub denied_values: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
         }
         #[derive(Clone, PartialEq, ::prost::Oneof)]
         pub enum Kind {
             /// List of values to be used for this PolicyRule. This field can be set
             /// only in Policies for list constraints.
-            #[prost(message, tag = "1")]
+            #[prost(message, tag="1")]
             Values(StringValues),
             /// Setting this to true means that all values are allowed. This field can
             /// be set only in Policies for list constraints.
-            #[prost(bool, tag = "2")]
+            #[prost(bool, tag="2")]
             AllowAll(bool),
             /// Setting this to true means that all values are denied. This field can
             /// be set only in Policies for list constraints.
-            #[prost(bool, tag = "3")]
+            #[prost(bool, tag="3")]
             DenyAll(bool),
             /// If `true`, then the `Policy` is enforced. If `false`, then any
             /// configuration is acceptable.
             /// This field can be set only in Policies for boolean constraints.
-            #[prost(bool, tag = "4")]
+            #[prost(bool, tag="4")]
             Enforce(bool),
         }
     }
@@ -267,16 +268,16 @@ pub struct ListConstraintsRequest {
     /// * `projects/{project_id}`
     /// * `folders/{folder_id}`
     /// * `organizations/{organization_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub parent: ::prost::alloc::string::String,
     /// Size of the pages to be returned. This is currently unsupported and will
     /// be ignored. The server may at any point start using this field to limit
     /// page size.
-    #[prost(int32, tag = "2")]
+    #[prost(int32, tag="2")]
     pub page_size: i32,
     /// Page token used to retrieve the next page. This is currently unsupported
     /// and will be ignored. The server may at any point start using this field.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub page_token: ::prost::alloc::string::String,
 }
 /// The response returned from the \[ListConstraints\]
@@ -284,10 +285,10 @@ pub struct ListConstraintsRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListConstraintsResponse {
     /// The collection of constraints that are available on the targeted resource.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub constraints: ::prost::alloc::vec::Vec<Constraint>,
     /// Page token used to retrieve the next page. This is currently not used.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub next_page_token: ::prost::alloc::string::String,
 }
 /// The request sent to the \[ListPolicies\]
@@ -301,16 +302,16 @@ pub struct ListPoliciesRequest {
     /// * `projects/{project_id}`
     /// * `folders/{folder_id}`
     /// * `organizations/{organization_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub parent: ::prost::alloc::string::String,
     /// Size of the pages to be returned. This is currently unsupported and will
     /// be ignored. The server may at any point start using this field to limit
     /// page size.
-    #[prost(int32, tag = "2")]
+    #[prost(int32, tag="2")]
     pub page_size: i32,
     /// Page token used to retrieve the next page. This is currently unsupported
     /// and will be ignored. The server may at any point start using this field.
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub page_token: ::prost::alloc::string::String,
 }
 /// The response returned from the \[ListPolicies\]
@@ -320,11 +321,11 @@ pub struct ListPoliciesRequest {
 pub struct ListPoliciesResponse {
     /// All `Policies` that exist on the resource. It will be empty if no
     /// `Policies` are set.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub policies: ::prost::alloc::vec::Vec<Policy>,
     /// Page token used to retrieve the next page. This is currently not used, but
     /// the server may at any point start supplying a valid token.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub next_page_token: ::prost::alloc::string::String,
 }
 /// The request sent to the \[GetPolicy\]
@@ -332,7 +333,7 @@ pub struct ListPoliciesResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetPolicyRequest {
     /// Required. Resource name of the policy. See `Policy` for naming requirements.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
 }
 /// The request sent to the \[GetEffectivePolicy\]
@@ -340,7 +341,7 @@ pub struct GetPolicyRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GetEffectivePolicyRequest {
     /// Required. The effective policy to compute. See `Policy` for naming rules.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
 }
 /// The request sent to the \[CreatePolicyRequest\]
@@ -353,10 +354,10 @@ pub struct CreatePolicyRequest {
     /// * `projects/{project_id}`
     /// * `folders/{folder_id}`
     /// * `organizations/{organization_id}`
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub parent: ::prost::alloc::string::String,
     /// Required. `Policy` to create.
-    #[prost(message, optional, tag = "3")]
+    #[prost(message, optional, tag="3")]
     pub policy: ::core::option::Option<Policy>,
 }
 /// The request sent to the \[UpdatePolicyRequest\]
@@ -364,7 +365,7 @@ pub struct CreatePolicyRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct UpdatePolicyRequest {
     /// Required. `Policy` to update.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub policy: ::core::option::Option<Policy>,
 }
 /// The request sent to the \[DeletePolicy\]
@@ -373,33 +374,33 @@ pub struct UpdatePolicyRequest {
 pub struct DeletePolicyRequest {
     /// Required. Name of the policy to delete.
     /// See `Policy` for naming rules.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
 }
-#[doc = r" Generated client implementations."]
+/// Generated client implementations.
 pub mod org_policy_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " An interface for managing organization policies."]
-    #[doc = ""]
-    #[doc = " The Cloud Org Policy service provides a simple mechanism for organizations to"]
-    #[doc = " restrict the allowed configurations across their entire Cloud Resource"]
-    #[doc = " hierarchy."]
-    #[doc = ""]
-    #[doc = " You can use a `policy` to configure restrictions in Cloud resources. For"]
-    #[doc = " example, you can enforce a `policy` that restricts which Google"]
-    #[doc = " Cloud Platform APIs can be activated in a certain part of your resource"]
-    #[doc = " hierarchy, or prevents serial port access to VM instances in a particular"]
-    #[doc = " folder."]
-    #[doc = ""]
-    #[doc = " `Policies` are inherited down through the resource hierarchy. A `policy`"]
-    #[doc = " applied to a parent resource automatically applies to all its child resources"]
-    #[doc = " unless overridden with a `policy` lower in the hierarchy."]
-    #[doc = ""]
-    #[doc = " A `constraint` defines an aspect of a resource's configuration that can be"]
-    #[doc = " controlled by an organization's policy administrator. `Policies` are a"]
-    #[doc = " collection of `constraints` that defines their allowable configuration on a"]
-    #[doc = " particular resource and its child resources."]
+    /// An interface for managing organization policies.
+    ///
+    /// The Cloud Org Policy service provides a simple mechanism for organizations to
+    /// restrict the allowed configurations across their entire Cloud Resource
+    /// hierarchy.
+    ///
+    /// You can use a `policy` to configure restrictions in Cloud resources. For
+    /// example, you can enforce a `policy` that restricts which Google
+    /// Cloud Platform APIs can be activated in a certain part of your resource
+    /// hierarchy, or prevents serial port access to VM instances in a particular
+    /// folder.
+    ///
+    /// `Policies` are inherited down through the resource hierarchy. A `policy`
+    /// applied to a parent resource automatically applies to all its child resources
+    /// unless overridden with a `policy` lower in the hierarchy.
+    ///
+    /// A `constraint` defines an aspect of a resource's configuration that can be
+    /// controlled by an organization's policy administrator. `Policies` are a
+    /// collection of `constraints` that defines their allowable configuration on a
+    /// particular resource and its child resources.
     #[derive(Debug, Clone)]
     pub struct OrgPolicyClient<T> {
         inner: tonic::client::Grpc<T>,
@@ -407,8 +408,8 @@ pub mod org_policy_client {
     impl<T> OrgPolicyClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -427,162 +428,186 @@ pub mod org_policy_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             OrgPolicyClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Lists `Constraints` that could be applied on the specified resource."]
+        /// Lists `Constraints` that could be applied on the specified resource.
         pub async fn list_constraints(
             &mut self,
             request: impl tonic::IntoRequest<super::ListConstraintsRequest>,
         ) -> Result<tonic::Response<super::ListConstraintsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.orgpolicy.v2.OrgPolicy/ListConstraints",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Retrieves all of the `Policies` that exist on a particular resource."]
+        /// Retrieves all of the `Policies` that exist on a particular resource.
         pub async fn list_policies(
             &mut self,
             request: impl tonic::IntoRequest<super::ListPoliciesRequest>,
         ) -> Result<tonic::Response<super::ListPoliciesResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.orgpolicy.v2.OrgPolicy/ListPolicies",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Gets a `Policy` on a resource."]
-        #[doc = ""]
-        #[doc = " If no `Policy` is set on the resource, NOT_FOUND is returned. The"]
-        #[doc = " `etag` value can be used with `UpdatePolicy()` to update a"]
-        #[doc = " `Policy` during read-modify-write."]
+        /// Gets a `Policy` on a resource.
+        ///
+        /// If no `Policy` is set on the resource, NOT_FOUND is returned. The
+        /// `etag` value can be used with `UpdatePolicy()` to update a
+        /// `Policy` during read-modify-write.
         pub async fn get_policy(
             &mut self,
             request: impl tonic::IntoRequest<super::GetPolicyRequest>,
         ) -> Result<tonic::Response<super::Policy>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.orgpolicy.v2.OrgPolicy/GetPolicy",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Gets the effective `Policy` on a resource. This is the result of merging"]
-        #[doc = " `Policies` in the resource hierarchy and evaluating conditions. The"]
-        #[doc = " returned `Policy` will not have an `etag` or `condition` set because it is"]
-        #[doc = " a computed `Policy` across multiple resources."]
-        #[doc = " Subtrees of Resource Manager resource hierarchy with 'under:' prefix will"]
-        #[doc = " not be expanded."]
+        /// Gets the effective `Policy` on a resource. This is the result of merging
+        /// `Policies` in the resource hierarchy and evaluating conditions. The
+        /// returned `Policy` will not have an `etag` or `condition` set because it is
+        /// a computed `Policy` across multiple resources.
+        /// Subtrees of Resource Manager resource hierarchy with 'under:' prefix will
+        /// not be expanded.
         pub async fn get_effective_policy(
             &mut self,
             request: impl tonic::IntoRequest<super::GetEffectivePolicyRequest>,
         ) -> Result<tonic::Response<super::Policy>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.orgpolicy.v2.OrgPolicy/GetEffectivePolicy",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Creates a Policy."]
-        #[doc = ""]
-        #[doc = " Returns a `google.rpc.Status` with `google.rpc.Code.NOT_FOUND` if the"]
-        #[doc = " constraint does not exist."]
-        #[doc = " Returns a `google.rpc.Status` with `google.rpc.Code.ALREADY_EXISTS` if the"]
-        #[doc = " policy already exists on the given Cloud resource."]
+        /// Creates a Policy.
+        ///
+        /// Returns a `google.rpc.Status` with `google.rpc.Code.NOT_FOUND` if the
+        /// constraint does not exist.
+        /// Returns a `google.rpc.Status` with `google.rpc.Code.ALREADY_EXISTS` if the
+        /// policy already exists on the given Cloud resource.
         pub async fn create_policy(
             &mut self,
             request: impl tonic::IntoRequest<super::CreatePolicyRequest>,
         ) -> Result<tonic::Response<super::Policy>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.orgpolicy.v2.OrgPolicy/CreatePolicy",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Updates a Policy."]
-        #[doc = ""]
-        #[doc = " Returns a `google.rpc.Status` with `google.rpc.Code.NOT_FOUND` if the"]
-        #[doc = " constraint or the policy do not exist."]
-        #[doc = " Returns a `google.rpc.Status` with `google.rpc.Code.ABORTED` if the etag"]
-        #[doc = " supplied in the request does not match the persisted etag of the policy"]
-        #[doc = ""]
-        #[doc = " Note: the supplied policy will perform a full overwrite of all"]
-        #[doc = " fields."]
+        /// Updates a Policy.
+        ///
+        /// Returns a `google.rpc.Status` with `google.rpc.Code.NOT_FOUND` if the
+        /// constraint or the policy do not exist.
+        /// Returns a `google.rpc.Status` with `google.rpc.Code.ABORTED` if the etag
+        /// supplied in the request does not match the persisted etag of the policy
+        ///
+        /// Note: the supplied policy will perform a full overwrite of all
+        /// fields.
         pub async fn update_policy(
             &mut self,
             request: impl tonic::IntoRequest<super::UpdatePolicyRequest>,
         ) -> Result<tonic::Response<super::Policy>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.orgpolicy.v2.OrgPolicy/UpdatePolicy",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Deletes a Policy."]
-        #[doc = ""]
-        #[doc = " Returns a `google.rpc.Status` with `google.rpc.Code.NOT_FOUND` if the"]
-        #[doc = " constraint or Org Policy does not exist."]
+        /// Deletes a Policy.
+        ///
+        /// Returns a `google.rpc.Status` with `google.rpc.Code.NOT_FOUND` if the
+        /// constraint or Org Policy does not exist.
         pub async fn delete_policy(
             &mut self,
             request: impl tonic::IntoRequest<super::DeletePolicyRequest>,
         ) -> Result<tonic::Response<()>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.cloud.orgpolicy.v2.OrgPolicy/DeletePolicy",
